@@ -4,13 +4,13 @@
 --
 --   This module includes three new types of 'MVar', namely 'Lock' (no associated value),
 --   'Var' (never empty) and 'Barrier' (filled at most once). See
---   <httpd://neilmitchell.blogspot.co.uk/2012/06/flavours-of-mvar_04.html this blog post>
+--   <https://neilmitchell.blogspot.co.uk/2012/06/flavours-of-mvar_04.html this blog post>
 --   for examples and justification.
 --
 --   If you need greater control of exceptions and threads
 --   see the <https://hackage.haskell.org/package/slave-thread slave-thread> package.
 --   If you need elaborate relationships between threads
---   see the <httdp://hackage.haskell.org/package/async async> package.
+--   see the <https://hackage.haskell.org/package/async async> package.
 module Control.Concurrent.Extra(
     module Control.Concurrent,
     withNumCapabilities,
@@ -18,7 +18,11 @@ module Control.Concurrent.Extra(
     -- * Lock
     Lock, newLock, withLock, withLockTry,
     -- * Var
-    Var, newVar, readVar, writeVar, modifyVar, modifyVar_, withVar,
+    Var, newVar, readVar,
+    writeVar, writeVar',
+    modifyVar, modifyVar',
+    modifyVar_, modifyVar_',
+    withVar,
     -- * Barrier
     Barrier, newBarrier, signalBarrier, waitBarrier, waitBarrierMaybe,
     ) where
@@ -30,6 +34,7 @@ import Data.Maybe
 import Data.Either.Extra
 import Data.Functor
 import Prelude
+import Data.Tuple.Extra (dupe)
 
 
 -- | On GHC 7.6 and above with the @-threaded@ flag, brackets a call to 'setNumCapabilities'.
@@ -152,14 +157,34 @@ readVar (Var x) = readMVar x
 writeVar :: Var a -> a -> IO ()
 writeVar v x = modifyVar_ v $ const $ pure x
 
+-- | Strict variant of 'writeVar'
+writeVar' :: Var a -> a -> IO ()
+writeVar' v x = modifyVar_' v $ const $ pure x
+
 -- | Modify a 'Var' producing a new value and a return result.
 modifyVar :: Var a -> (a -> IO (a, b)) -> IO b
 modifyVar (Var x) f = modifyMVar x f
 
+-- | Strict variant of 'modifyVar''
+modifyVar' :: Var a -> (a -> IO (a, b)) -> IO b
+modifyVar' x f = do
+    (newContents, res) <- modifyVar x $ \v -> do
+        (newContents, res) <- f v
+        pure (newContents, (newContents, res))
+    evaluate newContents
+    pure res
+
 -- | Modify a 'Var', a restricted version of 'modifyVar'.
 modifyVar_ :: Var a -> (a -> IO a) -> IO ()
 modifyVar_ (Var x) f = modifyMVar_ x f
 
+-- | Strict variant of 'modifyVar_'
+modifyVar_' :: Var a -> (a -> IO a) -> IO ()
+modifyVar_' x f = do
+    newContents <- modifyVar x (fmap dupe . f)
+    _ <- evaluate newContents
+    pure ()
+
 -- | Perform some operation using the value in the 'Var',
 --   a restricted version of 'modifyVar'.
 withVar :: Var a -> (a -> IO b) -> IO b
